File container
Format: {{ file_data['format_long_name'] }}
Filename: {{ file_data['basename'] }}
Video Streams
{% for stream in file_data['historictaskprobestreams_set'] %} {% if stream['codec_type'] == 'video' %}

#### {{ stream['codec_long_name'] }}

{% if 'avg_frame_rate' in stream %} Frame Rate: {{ stream['avg_frame_rate'] }}
{% end %} {% if 'bit_rate' in stream %} Bit Rate: {{ stream['bit_rate'] }}
{% end %} {% if 'coded_height' in stream %} Coded Height: {{ stream['coded_height'] }}
{% end %} {% if 'coded_width' in stream %} Coded Width: {{ stream['coded_width'] }}
{% end %} {% if 'height' in stream %} Height: {{ stream['height'] }}
{% end %} {% if 'width' in stream %} Width: {{ stream['width'] }}
{% end %} {% if 'duration' in stream %} Duration: {{ stream['duration'] }} seconds
{% end %}
{% end %} {% end %}
Audio Streams
{% for stream in file_data['historictaskprobestreams_set'] %} {% if stream['codec_type'] == 'audio' %}

#### {{ stream['codec_long_name'] }}

{% if 'channels' in stream %} Channels: {{ stream['channels'] }}
{% end %} {% if 'channel_layout' in stream %} Channel Layout: {{ stream['channel_layout'] }}
{% end %} {% if 'bit_rate' in stream %} Bit Rate: {{ stream['bit_rate'] }}
{% end %} {% if 'duration' in stream %} Duration: {{ stream['duration'] }} seconds
{% end %}
{% end %} {% end %}